#pragma once

#include <string>
#include <functional>
#include <vector>
#include "WatchyDisplay.h"

struct MenuItem
{
  std::string title;
  // If callback is set, when the menu item is selected, the callback will be called.
  // If pageNum is set, when the menu item is selected, the menu will switch to the page with the given pageNum.
  std::function<void()> callback;
  uint8_t pageNum;
};

enum MenuTextAlignment {
  ALIGNMENT_LEFT,
  ALIGNMENT_CENTER,
  ALIGNMENT_RIGHT
};

struct MenuPage
{
  uint8_t backPageNum;
  std::string title;
  MenuTextAlignment titleAlignment;
  std::string body;
  std::vector<MenuItem> menuItems;
};

class Menu
{
public:
  Menu();
  ~Menu();
  void Init(WatchyDisplay & display);
  void HandleButtonPress(uint64_t buttonMask);
  void SetPages(const std::vector<MenuPage> & pages);
  void SetExitCallback(std::function<void()> callback);
  void Redraw(bool partialRefresh = false);
  void Reset();

private:

  static RTC_DATA_ATTR WatchyDisplay * m_display;
  static RTC_DATA_ATTR std::function<void()> m_exitCallback;
  static RTC_DATA_ATTR uint8_t m_numPages, m_currentPage, m_numMenuItemsinCurrentPage, m_currentMenuItem, m_prevMenuItem;
  std::vector<MenuPage> m_pages;
};