#include "Clock.h"
#include "../SevenSegment.h"
#include "../Icons.h"
#include <Fonts/FreeSans9pt7b.h>
#include <Fonts/FreeSans12pt7b.h>
#include <sstream>

WatchFacePages::Clock::Clock(WatchyDisplay & display, WatchFeatures::WatchFeatures & features)
  : m_display(display), m_features(features)
{
}

void WatchFacePages::Clock::InitBoot()
{
}

void WatchFacePages::Clock::InitWake()
{
}

void WatchFacePages::Clock::DrawPage(bool partialRefresh)
{
  m_display.setFullWindow();

  m_display.fillScreen(GxEPD_WHITE);
  DrawBatteryIcon();

  // Get current time and offset by timezone
  tmElements_t currentTime;
  m_features.rtc.Get(currentTime);
  std::string date = m_features.rtc.GetDateString();
  int tzOffset = m_features.storage.GetTzOffset();
  m_features.rtc.OffsetTime(currentTime, tzOffset);


	SevenSegment sevenSegment(30, 60, 6, 5, 5);

  if (currentTime.Hour < 10) {
    sevenSegment.DrawDigit(m_display, 0, 15, 65, GxEPD_BLACK);
  } else {
    sevenSegment.DrawDigit(m_display, currentTime.Hour / 10, 20, 65, GxEPD_BLACK);
  }

  sevenSegment.DrawDigit(m_display, currentTime.Hour % 10, 60, 65, GxEPD_BLACK);

  if (currentTime.Minute < 10) {
    sevenSegment.DrawDigit(m_display, 0, 110, 65, GxEPD_BLACK);
  } else {
    sevenSegment.DrawDigit(m_display, currentTime.Minute / 10, 110, 65, GxEPD_BLACK);
  }

  sevenSegment.DrawDigit(m_display, currentTime.Minute % 10, 150, 65, GxEPD_BLACK);

  m_display.fillRect(97, 80, 5, 5, GxEPD_BLACK);
  m_display.fillRect(97, 100, 5, 5, GxEPD_BLACK);

  // Print day and date
  const char * weekDays[] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"};
  const char * dow = weekDays[currentTime.Wday - 1];

  m_display.setFont(&FreeSans9pt7b);
  m_display.setTextColor(GxEPD_BLACK);
  m_display.setCursor(15, 150);
  m_display.print(dow);

  int16_t x, y;
  uint16_t w, h;
  m_display.getTextBounds(date.c_str(), 0, 0, &x, &y, &w, &h);
  m_display.setCursor(180 - w, 150);
  m_display.print(m_features.rtc.GetDateString().c_str());

  // Seperator
  m_display.fillRect(15, 127, 170, 2, GxEPD_BLACK);

  // Steps
  m_display.setFont(&FreeSans12pt7b);
  m_display.setTextColor(GxEPD_BLACK);
  m_display.drawBitmap(10, 177, Icons::steps, 19, 23, GxEPD_BLACK);
  m_display.setCursor(40, 195);
  m_display.print(m_features.stepCounter.GetSteps());

  m_display.display(partialRefresh);
}

void WatchFacePages::Clock::DrawBatteryIcon()
{
  m_display.fillRect(200 - 48, 5, 43, 23, GxEPD_BLACK);
  m_display.fillRect(200 - 46, 7, 39, 19, GxEPD_WHITE);
  int intLevel = m_features.battery.GetPercentage();
  float level = intLevel / 100.0f;

  m_display.fillRect(200 - 44, 9, (int)std::round(35.0f * level), 15, GxEPD_BLACK);

  int16_t x = 200 - 85;
  if (intLevel == 100) {
    x -= 13;
  }

  std::ostringstream oss;
  oss << intLevel << "%";

  m_display.setFont(&FreeSans9pt7b);
  m_display.setTextColor(GxEPD_BLACK);

  int16_t y;
  uint16_t w, h;
  m_display.getTextBounds(oss.str().c_str(), 0, 0, &x, &y, &w, &h);

  m_display.setCursor(142 - w, 22);
  m_display.print(oss.str().c_str());
}